@@ -11,10 +11,11 @@ NO_SPACE_CHARS = (
     b'\xe2\x80\x8b', # zero-width-space
 )
 
-BI_SPACE_CHARS = {
+MULTI_SPACE_CHARS = {
     '⭐': '*',
     '【': '[',
     '】': ']',
+    '\t': ' ',
 }
 
 DEFAULT_RETRO_LAG = 0.00001
@@ -135,7 +136,7 @@ class FString(object):
 
     def __init__(self, init_string='', size=0, pad=' ', align='l', fg='', bg='', fx=[]):
 
-        self.fixed_size = True if size else False
+        self.fixed_size = size  # used by Row to decide whether to resize or not
 
         self.__input_string = ''
         self.append(init_string)
@@ -146,7 +147,6 @@ class FString(object):
         self.__pad = ' '
         self.pad = pad
 
-        # l, r, c, cl, lc, cr, rc
         self.__align = 'l'
         self.align = align
 
@@ -209,7 +209,7 @@ class FString(object):
         return len(self)
 
     @size.setter
-    def size(self, s=None):
+    def size(self, s):
         self.__output_size = int(s) if s else self.__input_size # desired len of output
 
     @property
@@ -296,7 +296,11 @@ class FString(object):
     @property
     def output(self):
 
-        self.__output = self.__input_string.replace('\t', ' ') # can't afford to have tabs in output as they are never displayed the same
+        tmp = self.__input_string
+        for k, v in MULTI_SPACE_CHARS.items():
+            # flatten these into single space chars
+            tmp = tmp.replace(k, v)
+        self.__output = tmp
 
         if self.__input_size > self.__output_size:
             self.__crop_output()
@@ -346,28 +350,29 @@ class FString(object):
 
 
 class Row(object):
-    '''a string with width === terminal_len (unless otherwise specified). Instantiate a Row object with str|FString instances and it will keep its width constant by cropping/aligning objects with no fixed_size'''
+    '''a string with size === terminal_len (unless otherwise specified). Instantiate a Row object with str|FString instances and it will keep its size constant by cropping/aligning objects with no fixed_size'''
 
-    def __init__(self, *items, width=False):
+    def __init__(self, *items, size=0):
         self.__output = ''
-        self.__fixed_width = width
+        self.__fixed_size = size
         self.__fstrings = []
         for item in items:
             self.append(item)
 
     def __len__(self):
-        return self.__fixed_width if self.__fixed_width else tty_cols()
+        return self.__fixed_size if self.__fixed_size else tty_cols()
 
     def assign_spaces(self):
-        spaces_left = self.width
+        spaces_left = len(self)
 
         # remove fixed_fs sizes
-        for fs in self.fixed_fstrings():
-            spaces_left -= len(fs)
+        for fs in self.__fstrings:
+            if fs.fixed_size:
+                spaces_left -= len(fs)
 
         # gather adaptive_fs
         adaptive_fs_count = len(
-            [ fs for fs in self.adaptive_fstrings() ]
+            [ fs for fs in self.__fstrings if not fs.fixed_size ]
         )
         if not adaptive_fs_count:
             return
@@ -403,8 +408,12 @@ class Row(object):
                     break
 
     @property
-    def width(self):
-        return len(self)
+    def size(self):
+        return self.__fixed_size
+
+    @size.setter
+    def size(self, s):
+        self.__fixed_size = s
 
     @property
     def output(self):
@@ -414,16 +423,6 @@ class Row(object):
             self.__output = self.__output + str(fs)
         return self.__output
 
-    def fixed_fstrings(self):
-        for fs in self.__fstrings:
-            if fs.fixed_size:
-                yield fs
-
-    def adaptive_fstrings(self):
-        for fs in self.__fstrings:
-            if not fs.fixed_size:
-                yield fs
-
     def append(self, s):
         self.__fstrings.append(
             FString(s) if type(s) != FString else s
